@@ -1,5 +1,5 @@
 // SPDX-FileCopyrightText: 2024 Nicolas Peugnet <nicolas@club1.fr>
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 package goldmark_ext
 
@@ -16,7 +16,7 @@ import (
 // manpageURLFmt is the format to use when producing the URL of a manpage.
 const manpageURLFmt = "https://manpages.debian.org/%s"
 
-var manpageLinkRegexp = regexp.MustCompile(`^[-\w\.]+\([1-9]\)`)
+var manpageLinkRegexp = regexp.MustCompile(`^[-\w\.]+\([1-9][a-z]*\)`)
 
 type manpageLinkParser struct{}
 
