@@ -1,5 +1,5 @@
 // SPDX-FileCopyrightText: 2024 Nicolas Peugnet <nicolas@club1.fr>
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 package goldmark_ext_test
 
@@ -52,6 +52,22 @@ func TestManpageLink(t *testing.T) {
 			`see very-looooooooooooong-page-name(1).`,
 			`<p>see <a href="https://manpages.debian.org/very-looooooooooooong-page-name(1)">very-looooooooooooong-page-name(1)</a>.</p>`,
 		},
+		{ // link to perl section
+			`deb-systemd-invoke(1p)`,
+			`<p><a href="https://manpages.debian.org/deb-systemd-invoke(1p)">deb-systemd-invoke(1p)</a></p>`,
+		},
+		{ // link to freebsd section
+			`intro(9freebsd)`,
+			`<p><a href="https://manpages.debian.org/intro(9freebsd)">intro(9freebsd)</a></p>`,
+		},
+		{ // no number in section
+			`intro(freebsd)`,
+			`<p>intro(freebsd)</p>`,
+		},
+		{ // number to big to be a section
+			`intro(42)`,
+			`<p>intro(42)</p>`,
+		},
 	}
 	for i, c := range cases {
 		t.Run(fmt.Sprintf("%d %s", i, c.src), func(t *testing.T) {
